@@ -9,8 +9,8 @@ draw_integer_array_dim2 <- function(n_i_1, replace_b_1 = TRUE) {
 df <- DataFactory()
 df$addSuffix('a', "array", draw_integer_array_dim2)
 
-Sys.setenv("OP_DATA_FACTORY" = "df")
-fg <- retrieveDataFactory() # retrieves the factory pointed by R variable df
+options('op_mt_data_factory' = df)
+fg <- retrieveDataFactory() # retrieves the user defined data factory
 ng <- nrow(fg$getRecordedTypes()[suffix == 'a'])
 
 test_that("retrieveDataFactory", {
@@ -20,7 +20,7 @@ test_that("retrieveDataFactory", {
 rm(fg)
 # wrong behavior as retrieveDataFactory will provide the default factory and not yours!
 
-Sys.setenv("OP_DATA_FACTORY" = "")
+options('op_mt_data_factory' = NULL)
 fh <- retrieveDataFactory() # retrieves the default factory
 nh <- nrow(fh$getRecordedTypes()[suffix == 'a'])
 
